@@ -95,12 +95,14 @@ class WaifuAioClient:
         return infos.get('url')
 
 
-    async def _fetchgallery(self, id, insert, delete, token):
+    async def _fetchgallery(self, user_id, toggle, insert, delete, token):
         """process the request for a specific tag and check if everything is correct."""
         params={}
         headers={}
-        if id:
-            params.update({'id':id})
+        if user_id:
+            params.update({'id':user_id})
+        if toggle:
+            params.update({'toggle':','.join(toggle)})
         if delete:
             params.update({'delete':','.join(delete)})
         if insert:
@@ -158,20 +160,21 @@ class WaifuAioClient:
         return data
 
     @requires_token
-    async def fav(self, id: str=None,insert: List[str]=None, delete: List[str]=None, token: str=None):
+    async def fav(self, user_id: str=None,toggle : List[str]=None,insert: List[str]=None, delete: List[str]=None, token: str=None):
         """Get your favorite gallery.""
 
         Kwargs:
             id: The user's id you want to access the gallery (only for trusted apps).
-            insert: A list of URL's that you want to add to your gallery in the same time.
-            delete: A list of URL's that you want to remove from your gallery in the same time.
+            toggle: A list of file names that you want to add if they do not already exist in, else remove, to your gallery in the same time.
+            insert: A list of file names that you want to add to your gallery in the same time.
+            delete: A list of file names that you want to remove from your gallery in the same time.
             token: The token that will be use for this request only, this doesnt change the token you passed in the class.
         Returns:
             A dictionnary containing the json the API returned.
         Raises:
             APIException: If the API response contains an error.
         """
-        return await self._fetchgallery(id,insert,delete,token)
+        return await self._fetchgallery(user_id,toggle,insert,delete,token)
 
     async def endpoints(self, full=False):
         """Gets the API endpoints.
